@@ -53,8 +53,7 @@
  */
 amdlibCOMPL_STAT amdlibCopyRegionInfo(amdlibREGION    *srcRegions, 
                                       amdlibREGION    *dstRegions, 
-                                      int             nbRegions,
-                                      amdlibERROR_MSG errMsg)
+                                      int             nbRegions)
 {
     int i, j;
 
@@ -288,8 +287,7 @@ amdlibCOMPL_STAT amdlibCopyScienceData(amdlibSCIENCE_DATA *srcScienceData,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopySelection(amdlibSELECTION *srcSelection,
-                                     amdlibSELECTION *dstSelection,
-                                     amdlibERROR_MSG errMsg)
+                                     amdlibSELECTION *dstSelection)
 {
     int band, base;
     
@@ -332,8 +330,7 @@ amdlibCOMPL_STAT amdlibCopySelection(amdlibSELECTION *srcSelection,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopyOiArray(amdlibOI_ARRAY  *srcOiArray,
-                                   amdlibOI_ARRAY  *dstOiArray,
-                                   amdlibERROR_MSG errMsg)
+                                   amdlibOI_ARRAY  *dstOiArray)
 {
     int s, i;
     
@@ -386,8 +383,7 @@ amdlibCOMPL_STAT amdlibCopyOiArray(amdlibOI_ARRAY  *srcOiArray,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopyOiTarget(amdlibOI_TARGET *srcOiTarget,
-                                    amdlibOI_TARGET *dstOiTarget,
-                                    amdlibERROR_MSG errMsg)
+                                    amdlibOI_TARGET *dstOiTarget)
 {
     int t;
     
@@ -440,8 +436,7 @@ amdlibCOMPL_STAT amdlibCopyOiTarget(amdlibOI_TARGET *srcOiTarget,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopyPhotometry(amdlibPHOTOMETRY *srcPhotometry, 
-                                      amdlibPHOTOMETRY *dstPhotometry, 
-                                      amdlibERROR_MSG   errMsg)
+                                      amdlibPHOTOMETRY *dstPhotometry)
 {
     int entry;
 
@@ -492,8 +487,7 @@ amdlibCOMPL_STAT amdlibCopyPhotometry(amdlibPHOTOMETRY *srcPhotometry,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopyVis(amdlibVIS *srcVis, 
-                               amdlibVIS *dstVis, 
-                               amdlibERROR_MSG   errMsg)
+                               amdlibVIS *dstVis)
 {
     int entry;
 
@@ -578,8 +572,7 @@ amdlibCOMPL_STAT amdlibCopyVis(amdlibVIS *srcVis,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopyVis2(amdlibVIS2 *srcVis2, 
-                                amdlibVIS2 *dstVis2, 
-                                amdlibERROR_MSG   errMsg)
+                                amdlibVIS2 *dstVis2)
 {
     int entry;
 
@@ -636,8 +629,7 @@ amdlibCOMPL_STAT amdlibCopyVis2(amdlibVIS2 *srcVis2,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopyVis3(amdlibVIS3 *srcVis3, 
-                                amdlibVIS3 *dstVis3, 
-                                amdlibERROR_MSG   errMsg)
+                                amdlibVIS3 *dstVis3)
 {
     int entry;
 
@@ -700,8 +692,7 @@ amdlibCOMPL_STAT amdlibCopyVis3(amdlibVIS3 *srcVis3,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopyPiston(amdlibPISTON *srcOpd, 
-                                  amdlibPISTON *dstOpd, 
-                                  amdlibERROR_MSG   errMsg)
+                                  amdlibPISTON *dstOpd)
 {
     int band;
     
@@ -747,8 +738,7 @@ amdlibCOMPL_STAT amdlibCopyPiston(amdlibPISTON *srcOpd,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopyWavelength(amdlibWAVELENGTH *srcWlen, 
-                                      amdlibWAVELENGTH *dstWlen, 
-                                      amdlibERROR_MSG   errMsg)
+                                      amdlibWAVELENGTH *dstWlen)
 {
     /* Copy fixed size fields */
     dstWlen->nbWlen = srcWlen->nbWlen;
@@ -777,8 +767,7 @@ amdlibCOMPL_STAT amdlibCopyWavelength(amdlibWAVELENGTH *srcWlen,
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
 amdlibCOMPL_STAT amdlibCopySpectrum(amdlibSPECTRUM  *srcSpectrum, 
-                                    amdlibSPECTRUM  *dstSpectrum, 
-                                    amdlibERROR_MSG errMsg)
+                                    amdlibSPECTRUM  *dstSpectrum)
 {
     int entry;
 
@@ -815,8 +804,7 @@ amdlibCOMPL_STAT amdlibCopySpectrum(amdlibSPECTRUM  *srcSpectrum,
  * @return
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
-amdlibCOMPL_STAT amdlibCopyBadPixelMap(amdlibBAD_PIXEL_MAP *dstBadPixel, 
-                                       amdlibERROR_MSG   errMsg)
+amdlibCOMPL_STAT amdlibCopyBadPixelMap(amdlibBAD_PIXEL_MAP *dstBadPixel)
 {
     /* Get current bad pixel map */
     amdlibBAD_PIXEL_MAP *srcBadPixel;
@@ -839,8 +827,7 @@ amdlibCOMPL_STAT amdlibCopyBadPixelMap(amdlibBAD_PIXEL_MAP *dstBadPixel,
  * @return
  * amdlibSUCCESS on successful completion. Otherwise amdlibFAILURE is returned.
  */
-amdlibCOMPL_STAT amdlibCopyFlatFieldMap(amdlibFLAT_FIELD_MAP *dstFlatField, 
-                                        amdlibERROR_MSG   errMsg)
+amdlibCOMPL_STAT amdlibCopyFlatFieldMap(amdlibFLAT_FIELD_MAP *dstFlatField)
 {
     /* Get current bad pixel map */
     amdlibFLAT_FIELD_MAP *srcFlatField;
