@@ -26,13 +26,13 @@ static int iminarg1,iminarg2;
 
 static amdmsCOMPL amdmsCalcQuality(amdmsFIT_ENV *env, int n, double *x, double *y, double *ye);
 
-static amdmsCOMPL amdmsFitLine(void *henv, int n, double *x, double *y, double *ye);
+static amdmsCOMPL amdmsFitLine(void *henv, int n, double *x, double *y);
 static double amdmsEvalLine(void *henv, double x);
 
-static amdmsCOMPL amdmsFitExp(void *env, int n, double *x, double *y, double *ye);
+static amdmsCOMPL amdmsFitExp(void *env, int n, double *x, double *y);
 static double amdmsEvalExp(void *env, double x);
 
-static amdmsCOMPL amdmsFitLog(void *henv, int n, double *x, double *y, double *ye);
+static amdmsCOMPL amdmsFitLog(void *henv, int n, double *x, double *y);
 static double amdmsEvalLog(void *henv, double x);
 
 static double amdmsCalcPythag(double a, double b);
@@ -58,13 +58,13 @@ static amdmsCOMPL amdmsAllocSpaceNonLinear(amdmsFIT_NONLINEAR_ENV *env, int nCs)
 static amdmsCOMPL amdmsFitNonLinear(void *henv, int n, double *x, double *y, double *ye);
 static double amdmsEvalNonLinear(void *henv, double x);
 
-static void amdmsNonLinearPixelInit(void *henv, int n, double *x, double *y, double *ye);
+static void amdmsNonLinearPixelInit(void *henv, int n, double *x, double *y);
 static void amdmsNonLinearPixelBaseFunc(double x, int na, double *a, double *y, double *dyda);
 
-static void amdmsElectronicBiasInit(void *henv, int n, double *x, double *y, double *ye);
+static void amdmsElectronicBiasInit(void *henv, int n, double *x, double *y);
 static void amdmsElectronicBiasBaseFunc(double x, int na, double *a, double *y, double *dyda);
 
-static void amdmsConversionFactorInit(void *henv, int n, double *x, double *y, double *ye);
+static void amdmsConversionFactorInit(void *henv, int n, double *x, double *y);
 static void amdmsConversionFactorBaseFunc(double x, int na, double *a, double *y, double *dyda);
 
 static amdmsCOMPL amdmsFindDataSaturation(amdmsFIT_DATA_ENV *env);
@@ -118,7 +118,7 @@ amdmsCOMPL amdmsCalcQuality(amdmsFIT_ENV *env, int n, double *x, double *y, doub
   return amdmsSUCCESS;
 }
 
-amdmsCOMPL amdmsFitLine(void *henv, int n, double *x, double *y, double *ye)
+amdmsCOMPL amdmsFitLine(void *henv, int n, double *x, double *y)
 {
   amdmsFIT_ENV *env = (amdmsFIT_ENV*)henv;
   int      i;
@@ -174,7 +174,7 @@ double amdmsEvalLine(void *henv, double x)
   }
 }
 
-amdmsCOMPL amdmsFitExp(void *henv, int n, double *x, double *y, double *ye)
+amdmsCOMPL amdmsFitExp(void *henv, int n, double *x, double *y)
 {
   amdmsFIT_ENV *env = (amdmsFIT_ENV*)henv;
   int      i;
@@ -213,7 +213,7 @@ double amdmsEvalExp(void *henv, double x)
   }
 }
 
-amdmsCOMPL amdmsFitLog(void *henv, int n, double *x, double *y, double *ye)
+amdmsCOMPL amdmsFitLog(void *henv, int n, double *x, double *y)
 {
   amdmsFIT_ENV *env = (amdmsFIT_ENV*)henv;
   int      i;
@@ -1299,7 +1299,7 @@ double amdmsEvalNonLinear(void *henv, double x)
   return y;
 }
 
-void amdmsNonLinearPixelInit(void *henv, int n, double *x, double *y, double *ye)
+void amdmsNonLinearPixelInit(void *henv, int n, double *x, double *y)
 {
   amdmsFIT_NONLINEAR_ENV  *env = (amdmsFIT_NONLINEAR_ENV*)henv;
   env->env.a[1] = 1.0;
@@ -1313,7 +1313,7 @@ void amdmsNonLinearPixelBaseFunc(double x, int na, double *a, double *y, double
     dyda[2] = (1 + a[2]*x - a[1]*x*x)/(1 + a[2]*x)/(1 + a[2]*x);
 }
 
-void amdmsGeneralExpInit(void *henv, int n, double *x, double *y, double *ye)
+void amdmsGeneralExpInit(void *henv, int n, double *x, double *y)
 {
   amdmsFIT_NONLINEAR_ENV  *env = (amdmsFIT_NONLINEAR_ENV*)henv;
   env->env.a[1] = 1.0;
@@ -1331,7 +1331,7 @@ void amdmsGeneralExpBaseFunc(double x, int na, double *a, double *y, double *dyd
 
 #define amdmsEBFIT_NCOEFF 3
 
-void amdmsElectronicBiasInit(void *henv, int n, double *x, double *y, double *ye)
+void amdmsElectronicBiasInit(void *henv, int n, double *x, double *y)
 {
   amdmsFIT_NONLINEAR_ENV  *env = (amdmsFIT_NONLINEAR_ENV*)henv;
   env->env.a[1] = 1.0;
@@ -1405,7 +1405,7 @@ void amdmsElectronicBiasBaseFunc(double x, int na, double *a, double *y, double
 /* a[1] = a */
 /* a[2] = g */
 /* a[3] = c */
-void amdmsConversionFactorInit(void *henv, int n, double *x, double *y, double *ye)
+void amdmsConversionFactorInit(void *henv, int n, double *x, double *y)
 {
   amdmsFIT_NONLINEAR_ENV  *env = (amdmsFIT_NONLINEAR_ENV*)henv;
   env->env.a[1] = 0.0;
